#include "dialog.h"
#include "ui_dialog.h"

#include <QMessageBox>
#include <QCloseEvent>
#include <QTimer>

#include "ni6221.h"

Dialog::Dialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Dialog),
    dev_(0)
{
    ui->setupUi(this);

    ui->cbStatus->setText("OFF");


    try {
        dev_ = new ni6221("/dev/comedi0");
        conv0 = new comedi::to_physical(dev_->getSubDevice(0)->hardcal_converter(0,0,COMEDI_TO_PHYSICAL));
        //conv1 = new comedi::to_physical(dev_->getSubDevice(1)->hardcal_converter(1,0,COMEDI_TO_PHYSICAL));
    }
    catch(std::runtime_error& err)
    {
        QMessageBox::critical(this,"Error opening card NI6221",err.what());
        dev_=0;
    }

    if (dev_)
    {
        QTimer *timer = new QTimer(this);
        connect(timer, SIGNAL(timeout()), this, SLOT(update()));
        timer->start(1000);
    }
    else
    {
        QTimer::singleShot(10, QCoreApplication::instance(), SLOT(quit()));
    }
}

void Dialog::closeEvent(QCloseEvent *e)
{
    if (dev_)
    {
        if (QMessageBox::warning(this,"Pressure Indicator","Sure you want to close this window?")==QMessageBox::Ok)
        {
            e->accept();
        }
        else e->ignore();
    }
    else QDialog::closeEvent(e);

}

Dialog::~Dialog()
{
    if (dev_) {
        delete dev_; dev_=0;
    }
    delete ui;
}

void Dialog::update()
{
    static int i = 0;


    ni6221::ai *ai = dev_->getAi();
    unsigned int v0 = ai->read(0,0,AREF_COMMON);
    unsigned int v1 = ai->read(1,0,AREF_COMMON);
    double d0 = conv0->operator ()(v0);
    double d1 = conv0->operator ()(v1);

    if (d0 < 0.5 || d0 > 10.)
    {
        d0 = 0.;
    }
    else // if (d0 < 1.9)
    {
        d0 = pow(10.,(d0-6.143)/1.286);
    }

    if (d1 < 0.667 || d1 > 10) d1 = 0;
    else d1 = pow(10.,(d1-12.66)/1.33);

    ui->lblP1->setText(QString::number(d0,'E',1));
    ui->lblP2->setText(QString::number(d1,'E',1));


    if (i==0) ui->cbStatus->setText("ON");

    ui->cbStatus->setChecked(i % 2);

    i++;


}
